==> alone-frame-1.0.4.tgz: package/nodes.js <==
import {execSync as exec} from "child_process";

import {createInterface} from "readline";

import {fileURLToPath} from "url";

import path from "path";

import fs from "fs";

import os from "os";

//删除路径多少层
export const dir_name = function (file, levels = 1) {
    for (let i = 0; i < levels; i++) {
        file = path.dirname(file);
    }
    return file;
};

//判断是否windows
export const is_win = function () {
    return os.platform() === 'win32';
};

//判断是否mac
export const is_mac = function () {
    return os.platform() === 'darwin';
};

//判断是否linux
export const is_linux = function () {
    return os.platform() === 'linux';
};

//node本地运行await import要使用此方法,解决windows问题
export const system_file = function (file) {
    return is_win() ? (file.includes("file://") ? file : ("file://" + file.replace(/\\/g, '/'))) : file;
}

//增加版本号
export const edit_ver = function (ver, add = '0.0.1') {
    const version = ver.split('.').map(Number);
    const increase = add.split('.').map(Number);
    while (version.length < increase.length) version.push(0);
    while (increase.length < version.length) increase.push(0);
    const parts = version.map((num, index) => num + increase[index]);
    for (let i = parts.length - 1; i > 0; i--) {
        if (parts[i] >= 10) {
            parts[i] -= 10;
            parts[i - 1] += 1;
        }
    }
    return parts.join('.');
};

//确认输入操作
export const confirm = function (title, callback) {
    const rl = createInterface({input: process.stdin, output: process.stdout});
    rl.question(title, (answer) => {
        callback(answer.toLowerCase());
        rl.close();
    });
}

//操作方法
export const nodes = function (dirname) {
    const self = {dirname: dirname || process.cwd(), fs: fs, path: path, os: os, exec: exec, readline: createInterface};
    //获取文件名
    self.get_path = function (file, type = true) {
        return type === true ? path.resolve(self.dirname, file) : file;
    };

    //判断文件或者目录是否存在
    self.is_exist = function (file, type = true) {
        return fs.existsSync(self.get_path(file, type));
    };

    //删除路径多少层
    self.dir_name = function (file, levels = 1) {
        return dir_name(file, levels);
    };

    //创建目录
    self.create_dir = function (dir, type = true) {
        if (!self.is_exist(dir, type)) {
            fs.mkdirSync(self.get_path(dir, type), {recursive: true});
        }
    };

    //删除目录
    self.delete_dir = function (dir, type = true) {
        if (self.is_exist(dir, type)) {
            fs.rmdirSync(self.get_path(dir, type));
        }
    }

    //删除文件
    self.delete_file = function (file, type = true) {
        if (self.is_exist(file, type)) {
            fs.unlinkSync(self.get_path(file, type));
        }
    }

    //目录内数量
    self.dir_count = function (dir, type = true) {
        if (self.is_exist(self.get_path(dir, type))) {
            const entries = fs.readdirSync(self.get_path(dir, type), {withFileTypes: true});
            return entries.length > 0;
        }
        return 0;
    };

    //复制指定文件
    self.cp_file = function (old_file, new_file, old_type = true, new_type = true) {
        self.create_dir(self.dir_name(new_file), new_type);
        if (self.is_exist(old_file, old_type)) {
            fs.copyFileSync(self.get_path(old_file, old_type), self.get_path(new_file, new_type));
        }
    };

    //复制目录,支持排除文件或者目录
    self.cp_dir_file = function (source, target, exclude = [], source_type = true, target_type = true, old_dir = '') {
        source = self.get_path(source, source_type);
        if (self.is_exist(source, source_type)) {
            self.create_dir(target, target_type);
            target = self.get_path(target, target_type);
            const list = fs.readdirSync(source, {withFileTypes: true});
            for (const val of list) {
                const dir_file_name = (val.parentPath + "/" + val.name).replace(old_dir ? old_dir : source, '').replace(/^\/|\/$/g, '');
                if (exclude && exclude.includes(dir_file_name)) {
                    continue;
                }
                const sour = path.join(source, val.name);
                const dest = path.join(target, val.name);
                if (val.isDirectory()) {
                    self.cp_dir_file(sour, dest, exclude, false, false, old_dir ? old_dir : source);
                } else {
                    fs.copyFileSync(sour, dest);
                }
            }
        }
    };

    //删除目录内文件,支持排除文件或者目录
    self.del_dir_file = function (dir, exclude = [], type = true, old_dir = '') {
        dir = self.get_path(dir, type);
        if (self.is_exist(dir, false)) {
            const files = fs.readdirSync(dir);
            for (const file of files) {
                const filePath = path.join(dir, file);
                const dir_file_name = filePath.replace(old_dir ? old_dir : dir, '').replace(/^\/|\/$/g, '');
                if (exclude && exclude.includes(dir_file_name)) {
                    continue;
                }
                if (fs.statSync(filePath).isDirectory()) {
                    self.del_dir_file(filePath, exclude, false, old_dir ? old_dir : dir);
                    if (self.dir_count(filePath, false) <= 0) {
                        fs.rmdirSync(filePath);
                    }
                } else {
                    fs.unlinkSync(filePath);
                }
            }
        }
    };

    //保存文件
    self.save_file = function (file, data, type = true) {
        const files = self.get_path(file, type);
        self.create_dir(self.dir_name(files), false);
        fs.writeFileSync(files, data);
        return files;
    };

    //获取文件
    self.get_file = function (file, type = true) {
        const files = self.get_path(file, type);
        if (self.is_exist(files, false)) {
            return fs.readFileSync(files, 'utf-8');
        }
        return null;
    };

    //保存json
    self.save_json = function (file, json, type = true) {
        try {
            return self.save_file(file, JSON.stringify(json, null, 2), type);
        } catch (e) {
            return self.get_path(file, type);
        }
    };

    //获取json
    self.get_json = function (file, type = true) {
        const data = self.get_file(file, type);
        try {
            if (data) {
                return JSON.parse(data);
            }
            return {};
        } catch (e) {
            return {};
        }
    };

    self.get_pack = function () {
        return self.get_json('package.json');
    }

    self.save_pack = function (data) {
        return self.save_json('package.json', data);
    }

    return self;
};
//获取当前模块
export const file_url = function (url = '') {
    return dir_name(fileURLToPath((url || import.meta.url)));
}
//上传和安装
export const npm_push_index = ({src, ver, version, push, create, pathname, dirname} = {}) => {
    const self = {
        src: src || 'src',
        pathname: pathname || file_url(),
        node: nodes(pathname || file_url()),
        dirname: (dirname || process.cwd()),
        del_src() {
            this.node.del_dir_file(this.src);
            this.node.delete_dir(this.src);
            return this;
        },
        del_name() {
            this.node_src.del_dir_file(this.pack.name);
            this.node_src.delete_dir(this.pack.name);
            return this;
        },
        copy_src({path, file = [], dir = []} = {}) {
            this.node_app = nodes(path);
            if (!this.node_app.is_exist('package.json')) {
                console.log("copy package not exist");
                return;
            }
            this.node_src = nodes(this.node.get_path((this.src)));
            this.node_name = nodes(this.node_src.get_path((this.pack.name)));
            const dir_file = (val) => {
                return this.node_name.get_path((val || '.').replace(/^\/+|\/+$/g, ''));
            }
            if (dir) {
                const dir_list = Array.isArray(dir) ? dir : Object.values(dir);
                dir_list.forEach((val) => {
                    this.node_app.cp_dir_file(val, dir_file(val), [], true, false)
                });
            }
            if (file) {
                const file_list = Array.isArray(file) ? file : Object.values(file);
                file_list.forEach((val) => {
                    this.node_app.cp_file(val, dir_file(val), true, false);
                });
            }
            return this;
        },
        push() {
            this.type = 'push';
            if (!this.node.is_exist('package.json')) {
                this.node = nodes(this.dirname);
                if (!this.node.is_exist('package.json')) {
                    this.node = null;
                }
            }
            if (!this.node) {
                console.log("package not exist");
                return;
            }
            //获取package
            this.pack = this.node.get_pack() || {};
            this.pack.version = (version || edit_ver(ver || this.pack.version || "1.0.0", '0.0.1'));
            this.pack.type = this.pack.type || "module";
            this.pack.license = this.pack.license || "license";
            this.pack.author = this.pack.author || "You";
            this.pack.scripts = this.pack.scripts || {};
            this.pack.scripts.push = this.pack.scripts.push || "node index.js";
            //是否create和显不的包名
            if (this.pack.name.startsWith("create")) {
                this.pack_create = true;
                this.pack_name = this.pack.name.split('-').slice(1).join('-');
                this.pack.files = [...new Set([...(this.pack.files || []), ...[this.src, "index.js"]])];
                this.pack.bin = this.pack.bin || {};
                this.pack.bin.cva = this.pack.bin.cva || "index.js";
                this.pack.bin[this.pack.name] = this.pack.bin[this.pack.name] || "index.js";
                this.pack.engines = this.pack.engines || {"node": "^18.0.0 || >=20.0.0"};
                this.node_src = nodes(this.node.get_path((this.src)));
                this.node_src.create_dir(this.pack.name);
            } else {
                this.pack_create = false;
                this.pack_name = this.pack.name;
            }
            this.pack.devDependencies = this.pack.devDependencies || {"@types/node": "^22.8.4"};
            (typeof push == 'function' && push(this, 1));
            console.log("\nnpm whoami");
            console.log("\nnpm publish");
            console.log("\nnpm config set //registry.npmjs.org/:_authToken <token>");
            console.log("\nhttps://www.npmjs.com/package/" + this.pack.name + "?activeTab=code\n");
            confirm('publish ? (y/n): ', (val) => {
                if (val == 'y') {
                    this.node.save_pack(this.pack);
                    this.node.exec('npm publish');
                    if (this.pack_create) {
                        console.log("\npnpm create " + this.pack_name + "@" + this.pack.version);
                        console.log("\nnpm create " + this.pack_name + "@latest");
                    } else {
                        console.log("\npnpm install " + this.pack.name + "@" + this.pack.version);
                        console.log("\nnpm install " + this.pack.name + "@latest");
                    }
                    console.log("\nhttps://www.npmjs.com/package/" + this.pack.name + "?activeTab=code\n");
                    (typeof push == 'function' && push(this, 2));
                }
            });
            return this;
        },
        create() {
            try {
                this.type = 'create';
                //获取npm安装目录
                if (!this.node.is_exist('package.json')) {
                    this.node = nodes(dir_name(process.argv[1]));
                    if (!this.node.is_exist('package.json')) {
                        const key = {
                            INIT_CWD: false,
                            PWD: false,
                            npm_config_local_prefix: false,
                            npm_package_json: true
                        };
                        for (const k in key) {
                            if (process.env[k]) {
                                this.node = nodes(((key[k] === true) ? dir_name(process.env[k]) : process.env[k]));
                                if (this.node.is_exist('package.json')) {
                                    break;
                                } else {
                                    this.node = null;
                                }
                            }
                        }
                    }
                }
                //找不到安装目录
                if (!this.node) {
                    console.log("npm directory not exist", process);
                    return;
                }
                //src目录
                this.node_src = nodes(this.node.get_path((this.src)));
                //用户目录
                this.user = nodes(this.dirname);
                //用户输入的项目名
                this.app_name = process.argv[2] || '';
                if (!this.app_name) {
                    this.app_arr = this.user.get_path('.').replace(/\\/g, '/').split('/').pop().split('-');
                    this.app_name = this.app_arr > 0 ? this.app_arr.slice(1).join('-') : this.app_arr.join('-');
                }
                this.app_name = this.app_name.replace(/\\/g, '/').replace(/^\/+|\/+$/g, '');
                //要复制的目录
                this.app_dir = process.argv[3] || '';
                //判断目录是否存在
                if (this.app_dir) {
                    if (!this.node_src.is_exist(this.app_dir)) {
                        this.app_dir = null;
                    }
                }
                //要复制的目录
                this.app_dir = this.app_dir || this.node.get_pack().name;
                this.app_dir = this.app_dir.replace(/\\/g, '/').replace(/^\/+|\/+$/g, '');
                if (!this.node_src.is_exist(this.app_dir)) {
                    console.log("directory not exist", this.app_dir);
                    return;
                }
                //删除用户目录
                this.user.del_dir_file(this.app_name);
                (typeof create == 'function' && create(this, 1));
                //开始复制目录到用户目录
                this.node_src.cp_dir_file(this.app_dir, this.user.get_path(this.app_name), [], true, false);
                //获取用户使用的命令类型
                this.command = {name: "npm", list: ['pnpm', 'yarn', 'bun', 'npm']};
                this.npm_dir = this.node.get_path('.').replace(/\\/g, '/');
                for (const val of this.command.list) {
                    if (
                        this.npm_dir.includes(val + '-') ||
                        this.npm_dir.includes('.' + val) ||
                        this.npm_dir.includes('/' + val) ||
                        this.npm_dir.includes(val + '/')
                    ) {
                        this.command.name = val;
                        break;
                    }
                }
                console.log("\ncd " + this.app_name + "\n");
                console.log(this.command.name + " install\n");
                console.log(this.command.name + " run dev\n");
                (typeof create == 'function' && create(this, 2));
            } catch (e) {
                console.log('error', e);
                console.log('argv', process.argv);
                console.log('import', import.meta);
                console.log('cwd', this.dirname);
                console.log('pathname', file_url());
            }
            return this;
        }
    };
    return self.node.is_exist('.npmignore') ? self.push() : self.create();
};
export default nodes;

==> alone-frame-1.0.5.tgz: package/nodes.js <==
import {execSync as exec} from "child_process";

import {createInterface} from "readline";

import {fileURLToPath} from "url";

import path from "path";

import fs from "fs";

import os from "os";

//删除路径多少层
export const dir_name = function (file, levels = 1) {
    for (let i = 0; i < levels; i++) {
        file = path.dirname(file);
    }
    return file;
};

//判断是否windows
export const is_win = function () {
    return os.platform() === 'win32';
};

//判断是否mac
export const is_mac = function () {
    return os.platform() === 'darwin';
};

//判断是否linux
export const is_linux = function () {
    return os.platform() === 'linux';
};

//node本地运行await import要使用此方法,解决windows问题
export const system_file = function (file) {
    return is_win() ? (file.includes("file://") ? file : ("file://" + file.replace(/\\/g, '/'))) : file;
}

//增加版本号
export const edit_ver = function (ver, add = '0.0.1') {
    const version = ver.split('.').map(Number);
    const increase = add.split('.').map(Number);
    while (version.length < increase.length) version.push(0);
    while (increase.length < version.length) increase.push(0);
    const parts = version.map((num, index) => num + increase[index]);
    for (let i = parts.length - 1; i > 0; i--) {
        if (parts[i] >= 10) {
            parts[i] -= 10;
            parts[i - 1] += 1;
        }
    }
    return parts.join('.');
};

//确认输入操作
export const confirm = function (title, callback) {
    const rl = createInterface({input: process.stdin, output: process.stdout});
    rl.question(title, (answer) => {
        callback(answer.toLowerCase());
        rl.close();
    });
}

//操作方法
export const nodes = function (dirname) {
    const self = {dirname: dirname || process.cwd(), fs: fs, path: path, os: os, exec: exec, readline: createInterface};
    //获取文件名
    self.get_path = function (file, type = true) {
        return type === true ? path.resolve(self.dirname, file) : file;
    };

    //判断文件或者目录是否存在
    self.is_exist = function (file, type = true) {
        return fs.existsSync(self.get_path(file, type));
    };

    //删除路径多少层
    self.dir_name = function (file, levels = 1) {
        return dir_name(file, levels);
    };

    //创建目录
    self.create_dir = function (dir, type = true) {
        if (!self.is_exist(dir, type)) {
            fs.mkdirSync(self.get_path(dir, type), {recursive: true});
        }
    };

    //删除目录
    self.delete_dir = function (dir, type = true) {
        if (self.is_exist(dir, type)) {
            fs.rmdirSync(self.get_path(dir, type));
        }
    }

    //删除文件
    self.delete_file = function (file, type = true) {
        if (self.is_exist(file, type)) {
            fs.unlinkSync(self.get_path(file, type));
        }
    }

    //目录内数量
    self.dir_count = function (dir, type = true) {
        if (self.is_exist(self.get_path(dir, type))) {
            const entries = fs.readdirSync(self.get_path(dir, type), {withFileTypes: true});
            return entries.length > 0;
        }
        return 0;
    };

    //复制指定文件
    self.cp_file = function (old_file, new_file, old_type = true, new_type = true) {
        self.create_dir(self.dir_name(new_file), new_type);
        if (self.is_exist(old_file, old_type)) {
            fs.copyFileSync(self.get_path(old_file, old_type), self.get_path(new_file, new_type));
        }
    };

    //复制目录,支持排除文件或者目录
    self.cp_dir_file = function (source, target, exclude = [], source_type = true, target_type = true, old_dir = '') {
        source = self.get_path(source, source_type);
        if (self.is_exist(source, source_type)) {
            self.create_dir(target, target_type);
            target = self.get_path(target, target_type);
            const list = fs.readdirSync(source, {withFileTypes: true});
            for (const val of list) {
                const dir_file_name = (val.parentPath + "/" + val.name).replace(old_dir ? old_dir : source, '').replace(/^\/|\/$/g, '');
                if (exclude && exclude.includes(dir_file_name)) {
                    continue;
                }
                const sour = path.join(source, val.name);
                const dest = path.join(target, val.name);
                if (val.isDirectory()) {
                    self.cp_dir_file(sour, dest, exclude, false, false, old_dir ? old_dir : source);
                } else {
                    fs.copyFileSync(sour, dest);
                }
            }
        }
    };

    //删除目录内文件,支持排除文件或者目录
    self.del_dir_file = function (dir, exclude = [], type = true, old_dir = '') {
        dir = self.get_path(dir, type);
        if (self.is_exist(dir, false)) {
            const files = fs.readdirSync(dir);
            for (const file of files) {
                const filePath = path.join(dir, file);
                const dir_file_name = filePath.replace(old_dir ? old_dir : dir, '').replace(/^\/|\/$/g, '');
                if (exclude && exclude.includes(dir_file_name)) {
                    continue;
                }
                if (fs.statSync(filePath).isDirectory()) {
                    self.del_dir_file(filePath, exclude, false, old_dir ? old_dir : dir);
                    if (self.dir_count(filePath, false) <= 0) {
                        fs.rmdirSync(filePath);
                    }
                } else {
                    fs.unlinkSync(filePath);
                }
            }
        }
    };

    //保存文件
    self.save_file = function (file, data, type = true) {
        const files = self.get_path(file, type);
        self.create_dir(self.dir_name(files), false);
        fs.writeFileSync(files, data);
        return files;
    };

    //获取文件
    self.get_file = function (file, type = true) {
        const files = self.get_path(file, type);
        if (self.is_exist(files, false)) {
            return fs.readFileSync(files, 'utf-8');
        }
        return null;
    };

    //保存json
    self.save_json = function (file, json, type = true) {
        try {
            return self.save_file(file, JSON.stringify(json, null, 2), type);
        } catch (e) {
            return self.get_path(file, type);
        }
    };

    //获取json
    self.get_json = function (file, type = true) {
        const data = self.get_file(file, type);
        try {
            if (data) {
                return JSON.parse(data);
            }
            return {};
        } catch (e) {
            return {};
        }
    };

    self.get_pack = function () {
        return self.get_json('package.json');
    }

    self.save_pack = function (data) {
        return self.save_json('package.json', data);
    }

    return self;
};
//获取当前模块
export const file_url = function (url = '') {
    return dir_name(fileURLToPath((url || import.meta.url)));
}
//上传和安装
export const npm_push_index = ({src, ver, version, push, create, pathname, dirname} = {}) => {
    const self = {
        src: src || 'src',
        pathname: pathname || file_url(),
        node: nodes(pathname || file_url()),
        dirname: (dirname || process.cwd()),
        del_src() {
            this.node.del_dir_file(this.src);
            this.node.delete_dir(this.src);
            return this;
        },
        del_name() {
            this.node_src.del_dir_file(this.pack.name);
            this.node_src.delete_dir(this.pack.name);
            return this;
        },
        copy_src({path, file = [], dir = []} = {}) {
            this.node_app = nodes(path);
            if (!this.node_app.is_exist('package.json')) {
                console.log("copy package not exist");
                return;
            }
            this.node_src = nodes(this.node.get_path((this.src)));
            this.node_name = nodes(this.node_src.get_path((this.pack.name)));
            const dir_file = (val) => {
                return this.node_name.get_path((val || '.').replace(/^\/+|\/+$/g, ''));
            }
            if (dir) {
                const dir_list = Array.isArray(dir) ? dir : Object.values(dir);
                dir_list.forEach((val) => {
                    this.node_app.cp_dir_file(val, dir_file(val), [], true, false)
                });
            }
            if (file) {
                const file_list = Array.isArray(file) ? file : Object.values(file);
                file_list.forEach((val) => {
                    this.node_app.cp_file(val, dir_file(val), true, false);
                });
            }
            return this;
        },
        push() {
            this.type = 'push';
            if (!this.node.is_exist('package.json')) {
                this.node = nodes(this.dirname);
                if (!this.node.is_exist('package.json')) {
                    this.node = null;
                }
            }
            if (!this.node) {
                console.log("package not exist");
                return;
            }
            //获取package
            this.pack = this.node.get_pack() || {};
            this.pack.version = (version || edit_ver(ver || this.pack.version || "1.0.0", '0.0.1'));
            this.pack.type = this.pack.type || "module";
            this.pack.license = this.pack.license || "license";
            this.pack.author = this.pack.author || "You";
            this.pack.scripts = this.pack.scripts || {};
            this.pack.scripts.push = this.pack.scripts.push || "node index.js";
            //是否create和显不的包名
            if (this.pack.name.startsWith("create")) {
                this.pack_create = true;
                this.pack_name = this.pack.name.split('-').slice(1).join('-');
                this.pack.files = [...new Set([...(this.pack.files || []), ...[this.src, "index.js"]])];
                this.pack.bin = this.pack.bin || {};
                this.pack.bin.cva = this.pack.bin.cva || "index.js";
                this.pack.bin[this.pack.name] = this.pack.bin[this.pack.name] || "index.js";
                this.pack.engines = this.pack.engines || {"node": "^18.0.0 || >=20.0.0"};
                this.node_src = nodes(this.node.get_path((this.src)));
                this.node_src.create_dir(this.pack.name);
            } else {
                this.pack_create = false;
                this.pack_name = this.pack.name;
            }
            this.pack.dependencies = this.pack.dependencies || {"@types/node": "^22.8.4"};
            (typeof push == 'function' && push(this, 1));
            console.log("\nnpm whoami");
            console.log("\nnpm publish");
            console.log("\nnpm config set //registry.npmjs.org/:_authToken <token>");
            console.log("\nhttps://www.npmjs.com/package/" + this.pack.name + "?activeTab=code\n");
            confirm('publish ? (y/n): ', (val) => {
                if (val == 'y') {
                    this.node.save_pack(this.pack);
                    this.node.exec('npm publish');
                    if (this.pack_create) {
                        console.log("\npnpm create " + this.pack_name + "@" + this.pack.version);
                        console.log("\nnpm create " + this.pack_name + "@latest");
                    } else {
                        console.log("\npnpm install " + this.pack.name + "@" + this.pack.version);
                        console.log("\nnpm install " + this.pack.name + "@latest");
                    }
                    console.log("\nhttps://www.npmjs.com/package/" + this.pack.name + "?activeTab=code\n");
                    (typeof push == 'function' && push(this, 2));
                }
            });
            return this;
        },
        create() {
            try {
                this.type = 'create';
                //获取npm安装目录
                if (!this.node.is_exist('package.json')) {
                    this.node = nodes(dir_name(process.argv[1]));
                    if (!this.node.is_exist('package.json')) {
                        const key = {
                            INIT_CWD: false,
                            PWD: false,
                            npm_config_local_prefix: false,
                            npm_package_json: true
                        };
                        for (const k in key) {
                            if (process.env[k]) {
                                this.node = nodes(((key[k] === true) ? dir_name(process.env[k]) : process.env[k]));
                                if (this.node.is_exist('package.json')) {
                                    break;
                                } else {
                                    this.node = null;
                                }
                            }
                        }
                    }
                }
                //找不到安装目录
                if (!this.node) {
                    console.log("npm directory not exist", process);
                    return;
                }
                //src目录
                this.node_src = nodes(this.node.get_path((this.src)));
                //用户目录
                this.user = nodes(this.dirname);
                //用户输入的项目名
                this.app_name = process.argv[2] || '';
                if (!this.app_name) {
                    this.app_arr = this.user.get_path('.').replace(/\\/g, '/').split('/').pop().split('-');
                    this.app_name = this.app_arr > 0 ? this.app_arr.slice(1).join('-') : this.app_arr.join('-');
                }
                this.app_name = this.app_name.replace(/\\/g, '/').replace(/^\/+|\/+$/g, '');
                //要复制的目录
                this.app_dir = process.argv[3] || '';
                //判断目录是否存在
                if (this.app_dir) {
                    if (!this.node_src.is_exist(this.app_dir)) {
                        this.app_dir = null;
                    }
                }
                //要复制的目录
                this.app_dir = this.app_dir || this.node.get_pack().name;
                this.app_dir = this.app_dir.replace(/\\/g, '/').replace(/^\/+|\/+$/g, '');
                if (!this.node_src.is_exist(this.app_dir)) {
                    console.log("directory not exist", this.app_dir);
                    return;
                }
                //删除用户目录
                this.user.del_dir_file(this.app_name);
                (typeof create == 'function' && create(this, 1));
                //开始复制目录到用户目录
                this.node_src.cp_dir_file(this.app_dir, this.user.get_path(this.app_name), [], true, false);
                //获取用户使用的命令类型
                this.command = {name: "npm", list: ['pnpm', 'yarn', 'bun', 'npm']};
                this.npm_dir = this.node.get_path('.').replace(/\\/g, '/');
                for (const val of this.command.list) {
                    if (
                        this.npm_dir.includes(val + '-') ||
                        this.npm_dir.includes('.' + val) ||
                        this.npm_dir.includes('/' + val) ||
                        this.npm_dir.includes(val + '/')
                    ) {
                        this.command.name = val;
                        break;
                    }
                }
                console.log("\ncd " + this.app_name + "\n");
                console.log(this.command.name + " install\n");
                console.log(this.command.name + " run dev\n");
                (typeof create == 'function' && create(this, 2));
            } catch (e) {
                console.log('error', e);
                console.log('argv', process.argv);
                console.log('import', import.meta);
                console.log('cwd', this.dirname);
                console.log('pathname', file_url());
            }
            return this;
        }
    };
    return self.node.is_exist('.npmignore') ? self.push() : self.create();
};
export default nodes;
